AdjustedAddress

Enum AdjustedAddress 

pub enum AdjustedAddress {
    NonCanonical(Address),
    NullPointerWithOffset(AddressOffset),
}
Info about a memory address that was adjusted from its reported value

There will be situations where the memory address reported by the OS is sub-optimal for debugging purposes, such as when an array is accidently indexed into with a null pointer base, at which point the address might read something like 0x00001000 when the more-useful address would just be zero.

If such a correction was made, this will be included in ExceptionInfo.

Variants



NonCanonical(Address)

The original access was an Amd64 “non-canonical” address; actual address is provided here.



NullPointerWithOffset(AddressOffset)

The base pointer was null; offset from base is provided here.