pub struct BitFlipDetails {
    pub was_non_canonical: bool,
    pub is_null: bool,
    pub was_low: bool,
    pub nearby_registers: u32,
    pub poison_registers: bool,
}

Fields

was_non_canonical: bool

The bit flip caused a non-canonical address access.

is_null: bool

The corrected address is null.

was_low: bool

The original address was fairly low.

This is only populated if is_null is true, and may indicate that a bit flip didn’t occur (and the original value was merely a small value which is more likely to be produced by booleans, iteration, etc).

nearby_registers: u32

The number of registers near the corrected address.

This will only be populated for sufficiently high addresses (to avoid high false positive rates).

poison_registers: bool

There are poison patterns in one or more registers.

This may indicate that a bit flip didn’t occur, and instead there was a UAF.

Implementations

source

impl BitFlipDetails

source

pub fn confidence(&self) -> f32

Calculate a confidence level between 0 and 1 pertaining to the bit flip likelihood.