Struct minidump_processor::CallStack [−][src]
pub struct CallStack {
pub frames: Vec<StackFrame>,
pub info: CallStackInfo,
pub thread_name: Option<String>,
pub last_error_value: Option<CrashReason>,
}Expand description
A stack of StackFrames produced as a result of unwinding a thread.
Fields
frames: Vec<StackFrame>The stack frames. By convention, the stack frame at index 0 is the innermost callee frame, and the frame at the highest index in a call stack is the outermost caller.
info: CallStackInfoInformation about this CallStack.
thread_name: Option<String>The name of the thread, if known.
last_error_value: Option<CrashReason>The GetLastError() value stored in the TEB.
Implementations