#[non_exhaustive]pub struct PendingProcessorStatSubscriptions {
pub thread_count: bool,
pub frame_count: bool,
pub unwalked_result: bool,
pub live_frames: bool,
}Expand description
Live updates you want to subscribe to during the processing.
Pass this into PendingProcessorStats::new to configure it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.thread_count: boolSubscribe to stats on how many threads have been processed.
This can be used to give a progress estimate.
The values can be read with PendingProcessorStats::get_thread_count.
frame_count: boolSubscribe to stats on how many frames have been processed.
This can be used to give a progress estimate.
The value can be read with PendingProcessorStats::get_frame_count.
unwalked_result: boolSubscribe to a copy of the ProcessState before stackwalking (or symbolication).
This can be used to provide the quick and easy results while the expensive stackwalker has to go off and start doing file or network i/o for symbols.
The values can be read with PendingProcessorStats::take_unwalked_result.
live_frames: boolSubscribe to live StackFrame results.
This can be used to update PendingProcessorStatSubscriptions::unwalked_result
as the stackwalker makes progress. How useful/smooth this is depends on the input.
If the biggest symbol file is the first frame of the stack, the walker may hang at 0%
progress for a long time and then suddenly jump to 100% instantly, as the
first dependency gets resolved last.
The values can be read with PendingProcessorStats::drain_new_frames.